<?php

namespace App\Http\Controllers\API;

use App\Models\Payment;
use Illuminate\Http\Request;
use App\Http\Resources\PaymentResource;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\API\ApiController;

class PaymentController extends ApiController
{
    public function index() 
    {
        return $this->successResponse('Payments successfully fetched.',PaymentResource::collection(Payment::all()));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'regid' => 'required',
            'amount' => 'required',
            'paymentmethod' => 'required',
            'remarks' => '',
            'paymentdate' => 'required',
        ]);

        if ($validator->fails()) {
            return $this->errorResponse('Error validation.', $validator->errors());       
        }
        return $this->successResponse('Payment successfully created.', new PaymentResource(
        	Payment::create($validator->validated())
        ));
        
    }

   
    public function show($id)
    {
        $payment = Payment::find($id);

        if (is_null($payment)) {
            return $this->errorResponse('Payment does not exist.');
        }
        return $this->successResponse('Payment successfully fetched.', new PaymentResource($payment));
    }
    

    public function update(Request $request, Registration $payment)
    {
        $validator = Validator::make($request->all(), [
            'regid' => 'required',
            'amount' => 'required',
            'remarks' => '',
            'paymentmethod' => 'required',
        ]);

        if($validator->fails()){
            return $this->errorResponse('Error validation.', $validator->errors());       
        }

        $input = $validator->validated();

        $payment->regid = $input['regid'];
        $payment->amount = $input['amount'];
        $payment->remarks = $input['remarks'];

        $payment->save();
        
        return $this->successResponse('Payment successfully updated.', new PaymentResource($payment));
    }
   
    public function destroy($id)
    {
    	$payment = Payment::find($id);

        if (is_null($registration)) {
            return $this->errorResponse('Payment does not exist.');
        }

        $payment->delete();

        return $this->successResponse('Payment successfully deleted.');
    }
}
