<?php

namespace App\Http\Controllers\API;

use App\Models\Registration;
use Illuminate\Http\Request;
use App\Http\Resources\RegistrationResource;
use Illuminate\Support\Facades\Validator;
use App\Http\Controllers\API\ApiController;

class RegistrationController extends ApiController
{
    public function index()
    {
        return $this->successResponse('Registration successfully fetched.', RegistrationResource::collection(Registration::all()));
    }

    
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'firstname' => 'required',
            'middleinitial' => 'required',
            'lastname' => 'required',
            'age' => 'required',
            'barangay' => 'required',
            'municipality' => 'required',
            'province' => 'required',
            'gender' => 'required',
            'mobileno' => 'required',
            //'cardserialno' => '',
            'kmtorun' => 'required',
            'regid' => 'required',
            'posted' => 'required',
            'paid' => 'required',
            'datecreated' => '',
            'dateuploaded' => '',
            'datemodified' => ''
        ]);

        if ($validator->fails()) {
            return $this->errorResponse('Error validation.', $validator->errors());       
        }
        return $this->successResponse('Post successfully created.', new RegistrationResource(
        	Registration::create($validator->validated())
        ));
        
    }

   
    public function show($id)
    {
        $registration = Registration::find($id);

        if (is_null($registration)) {
            return $this->errorResponse('Registration does not exist.');
        }
        return $this->successResponse('Registration successfully fetched.', new RegistrationResource($registration));
    }


    public function update(Request $request, Registration $registration)
    {
        $validator = Validator::make($request->all(), [
            'firstname' => 'required',
            'middleinitial' => 'required',
            'lastname' => 'required',
            'age' => 'required',
            'barangay' => 'required',
            'municipality' => 'required',
            'province' => 'required',
            'gender' => 'required',
            'mobileno' => 'required',
            'cardserialno' => '',
            'kmtorun' => 'required',
            'regid' => 'required',
            'posted' => 'required',
            'paid' => '',
            'datemodified' => 'required',
            'dateuploaded' => '',
        ]);

        if($validator->fails()){
            return $this->errorResponse('Error validation.', $validator->errors());       
        }

        $input = $validator->validated();

        $registration->firstname = $input['firstname'];
        $registration->middleinitial = $input['middleinitial'];
        $registration->lastname = $input['lastname'];
        $registration->age = $input['age'];
        $registration->barangay = $input['barangay'];
        $registration->municipality = $input['municipality'];
        $registration->province = $input['province'];
        $registration->gender = $input['gender'];
        $registration->mobileno = $input['mobileno'];
        $registration->kmtorun = $input['kmtorun'];
        $registration->cardserialno = $input['cardserialno'];
        $registration->regid = $input['regid'];
        $registration->posted = $input['posted'];
        $registration->paid = $input['paid'];
        $registration->datemodified = $input['datemodified'];
        $registration->dateuploaded = $input['dateuploaded'];

        $registration->save();
        
        return $this->successResponse('Registration successfully updated.', new RegistrationResource($registration));
    }
   
    public function destroy($id)
    {
    	$registration = Registration::find($id);

        if (is_null($registration)) {
            return $this->errorResponse('Registration does not exist.');
        }

        $registration->delete();

        return $this->successResponse('Registration successfully deleted.');
    }
}
